Learn R Programming

stoichUtilities (version 1.0.2)

stoichUtilities-package: stoichUtilities: User Tools for Accessing the STOICH Project Database

Description

User tools for working with The STOICH Project (Stoichiometric Traits of Organisms in their Chemical Habitats) database https://snr-stoich.unl.edu/. This package is designed to aid in data discovery, filtering, pairing water samples with organism samples, and merging data tables to assist users in preparing data for analyses. For additional examples see "Additional Examples" and the readme file at https://github.com/STOICH-project/STOICH-utilities.

Arguments

Author

Maintainer: Chad Petersen cpetersen4@unl.edu

Other contributors:

See Also