User tools for working with The STOICH Project (Stoichiometric Traits of Organisms in their Chemical Habitats) database https://snr-stoich.unl.edu/. This package is designed to aid in data discovery, filtering, pairing water samples with organism samples, and merging data tables to assist users in preparing data for analyses. For additional examples see "Additional Examples" and the readme file at https://github.com/STOICH-project/STOICH-utilities.
Maintainer: Chad Petersen cpetersen4@unl.edu
Other contributors:
Jessica Corman jcorman3@unl.edu [contributor]
Halvor Halvorson hhalvorson@uca.edu [contributor]
Casey Brucker cbrucker@uwyo.edu [contributor]
Eli Wess ewess@uca.edu [contributor]
U.S. National Science Foundation [funder]